==> testflows.github.runners-1.3.230729.1235004.tar.gz: testflows.github.runners-1.3.230729.1235004/testflows/github/runners/service.py <==
# Copyright 2023 Katteli Inc.
# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import os
import sys

NAME = "github-runners"
SERVICE = f"/etc/systemd/system/{NAME}.service"

from .actions import Action


def command_options(config):
    """Build service install command options not including:

    --github-token
    --github-repository
    --hetzner-token
    --ssh-key
    """
    command = ""
    command += f" --github-token $GITHUB_TOKEN"
    command += f" --github-repository $GITHUB_REPOSITORY"
    command += f" --hetzner-token $HETZNER_TOKEN"
    command += f" --config {config.config_file}" if config.config_file else ""
    command += f" --workers {config.workers}"
    command += f" --default-type {config.default_server_type.name}"
    command += (
        f" --default-location {config.default_location.name}"
        if config.default_location
        else ""
    )
    command += f" --default-image {config.default_image.type}:{config.default_image.name or config.default_image.description}"
    command += f" --max-runners {config.max_runners}" if config.max_runners else ""
    command += f" --setup-script {config.setup_script}" if config.setup_script else ""
    command += (
        f" --startup-x64-script {config.startup_x64_script}"
        if config.startup_x64_script
        else ""
    )
    command += (
        f" --startup-arm64-script {config.startup_arm64_script}"
        if config.startup_arm64_script
        else ""
    )
    command += (
        f" --max-powered-off-time {config.max_powered_off_time}"
        f" --max-unused-runner-time {config.max_unused_runner_time}"
        f" --max-runner-registration-time {config.max_runner_registration_time}"
        f" --max-server-ready-time {config.max_server_ready_time}"
        f" --scale-up-interval {config.scale_up_interval}"
        f" --scale-down-interval {config.scale_down_interval}"
    )
    command += f" --debug" if config.debug else ""

    return command


def install(args, config):
    """Install service."""
    config.check()
    force = args.force
    current_dir = os.path.dirname(__file__)

    with Action("Checking if service is already installed"):
        if os.path.exists(SERVICE):
            if not force:
                raise ValueError("service has already been installed")
            with Action("Stopping service"):
                os.system(f"sudo service {NAME} stop")

    with Action(f"Installing {SERVICE}"):
        binary = os.path.join(current_dir, "bin", "github-runners")
        contents = (
            "[Unit]\n"
            "Description=Autoscaling GitHub Actions Runners\n"
            "After=multi-user.target\n"
            "[Service]\n"
            f"User={os.getuid()}\n"
            f"Group={os.getgid()}\n"
            "Type=simple\n"
            "Restart=always\n"
            f"Environment=GITHUB_TOKEN={config.github_token}\n"
            f"Environment=GITHUB_REPOSITORY={config.github_repository}\n"
            f"Environment=HETZNER_TOKEN={config.hetzner_token}\n"
            f"ExecStart={binary}"
        )
        contents += f" --ssh-key {config.ssh_key}"
        contents += command_options(config)
        contents += "\n" "[Install]\n" "WantedBy=multi-user.target\n"

        os.system(f"sudo bash -c \"cat > {SERVICE}\" <<'EOF'\n{contents}\nEOF")
        os.system(f"sudo chmod 700 {SERVICE}")

    with Action("Reloading systemd"):
        os.system("sudo systemctl daemon-reload")

    with Action("Enabling service"):
        os.system(f"sudo systemctl enable {NAME}.service")

    with Action("Starting service"):
        os.system(f"sudo service {NAME} start")


def uninstall(args, config=None):
    """Uninstall service."""
    with Action("Stopping service"):
        os.system(f"sudo service {NAME} stop")

    with Action("Disabling service"):
        os.system(f"sudo systemctl disable {NAME}.service")

    with Action(f"Removing {SERVICE}"):
        os.system(f"sudo rm -f {SERVICE}")

    with Action("Reloading systemd"):
        os.system("sudo systemctl daemon-reload")


def logs(args, config=None):
    """Get service logs."""
    os.system(
        f'sudo bash -c "journalctl -u {NAME}.service'
        + (" -f" if args.follow else "")
        + ' | tee"'
    )


def start(args, config=None):
    """Start service."""
    os.system(f"sudo service {NAME} start")


def stop(args, config=None):
    """Stop service."""
    os.system(f"sudo service {NAME} stop")


def status(args, config=None):
    """Get service status."""
    os.system(f"sudo service {NAME} status")

==> testflows.github.runners-1.3.230801.1152824.tar.gz: testflows.github.runners-1.3.230801.1152824/testflows/github/runners/service.py <==
# Copyright 2023 Katteli Inc.
# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import os
import sys

NAME = "github-runners"
SERVICE = f"/etc/systemd/system/{NAME}.service"

from .actions import Action


def command_options(config):
    """Build service install command options not including:

    --github-token
    --github-repository
    --hetzner-token
    --ssh-key
    """
    command = ""
    command += f" --github-token $GITHUB_TOKEN"
    command += f" --github-repository $GITHUB_REPOSITORY"
    command += f" --hetzner-token $HETZNER_TOKEN"
    command += f" --config {config.config_file}" if config.config_file else ""
    command += f" --workers {config.workers}"
    command += f" --default-type {config.default_server_type.name}"
    command += (
        f" --default-location {config.default_location.name}"
        if config.default_location
        else ""
    )
    command += f" --default-image {config.default_image.architecture}:{config.default_image.type}:{config.default_image.name or config.default_image.description}"
    command += f" --max-runners {config.max_runners}" if config.max_runners else ""
    command += f" --setup-script {config.setup_script}" if config.setup_script else ""
    command += (
        f" --startup-x64-script {config.startup_x64_script}"
        if config.startup_x64_script
        else ""
    )
    command += (
        f" --startup-arm64-script {config.startup_arm64_script}"
        if config.startup_arm64_script
        else ""
    )
    command += (
        f" --max-powered-off-time {config.max_powered_off_time}"
        f" --max-unused-runner-time {config.max_unused_runner_time}"
        f" --max-runner-registration-time {config.max_runner_registration_time}"
        f" --max-server-ready-time {config.max_server_ready_time}"
        f" --scale-up-interval {config.scale_up_interval}"
        f" --scale-down-interval {config.scale_down_interval}"
    )
    command += f" --debug" if config.debug else ""

    return command


def install(args, config):
    """Install service."""
    config.check()
    force = args.force
    current_dir = os.path.dirname(__file__)

    with Action("Checking if service is already installed"):
        if os.path.exists(SERVICE):
            if not force:
                raise ValueError("service has already been installed")
            with Action("Stopping service"):
                os.system(f"sudo service {NAME} stop")

    with Action(f"Installing {SERVICE}"):
        binary = os.path.join(current_dir, "bin", "github-runners")
        contents = (
            "[Unit]\n"
            "Description=Autoscaling GitHub Actions Runners\n"
            "After=multi-user.target\n"
            "[Service]\n"
            f"User={os.getuid()}\n"
            f"Group={os.getgid()}\n"
            "Type=simple\n"
            "Restart=always\n"
            f"Environment=GITHUB_TOKEN={config.github_token}\n"
            f"Environment=GITHUB_REPOSITORY={config.github_repository}\n"
            f"Environment=HETZNER_TOKEN={config.hetzner_token}\n"
            f"ExecStart={binary}"
        )
        contents += f" --ssh-key {config.ssh_key}"
        contents += command_options(config)
        contents += "\n" "[Install]\n" "WantedBy=multi-user.target\n"

        os.system(f"sudo bash -c \"cat > {SERVICE}\" <<'EOF'\n{contents}\nEOF")
        os.system(f"sudo chmod 700 {SERVICE}")

    with Action("Reloading systemd"):
        os.system("sudo systemctl daemon-reload")

    with Action("Enabling service"):
        os.system(f"sudo systemctl enable {NAME}.service")

    with Action("Starting service"):
        os.system(f"sudo service {NAME} start")


def uninstall(args, config=None):
    """Uninstall service."""
    with Action("Stopping service"):
        os.system(f"sudo service {NAME} stop")

    with Action("Disabling service"):
        os.system(f"sudo systemctl disable {NAME}.service")

    with Action(f"Removing {SERVICE}"):
        os.system(f"sudo rm -f {SERVICE}")

    with Action("Reloading systemd"):
        os.system("sudo systemctl daemon-reload")


def logs(args, config=None):
    """Get service logs."""
    os.system(
        f'sudo bash -c "journalctl -u {NAME}.service'
        + (" -f" if args.follow else "")
        + ' | tee"'
    )


def start(args, config=None):
    """Start service."""
    os.system(f"sudo service {NAME} start")


def stop(args, config=None):
    """Stop service."""
    os.system(f"sudo service {NAME} stop")


def status(args, config=None):
    """Get service status."""
    os.system(f"sudo service {NAME} status")
